@@ -5,4 +5,7 @@ Billy Zoellers
 CLI tools for managing Meraki networks based on Typer
 """
 from rich.console import Console
-console = Console()
\ No newline at end of file
+from rich.traceback import install
+
+console = Console()
+install(show_locals=True, console=console)
\ No newline at end of file
