@@ -35,4 +35,26 @@ class DeviceSortOptions(str, Enum):
   Options to sort a list of devices
   """
   name = "name"
-  model = "model"
\ No newline at end of file
+  model = "model"
+
+class MXInternetUplinks(str, Enum):
+  """
+  Uplink types on an MX device
+  """
+  one = "internet1"
+  two = "internet2"
+
+class TrafficDirection(str, Enum):
+  """
+  Directions traffic can flow from an interface
+  """
+  total = "total"
+  recv = "recv"
+  sent = "sent"
+
+class MSInterfaceMode(str, Enum):
+  """
+  Interface modes on an MS switch
+  """
+  access = "access"
+  trunk = "trunk"
\ No newline at end of file
